@@ -4,7 +4,6 @@
  * @brief Graph class source file
  */
 
-#include <stdlib.h>
 #include <assert.h>
 #include <algorithm>
 #include <stack>
@@ -14,13 +13,13 @@
 
 namespace spoa {
 
-constexpr uint32_t kMaxAlphabetSize = 256;
+constexpr std::uint32_t kMaxAlphabetSize = 256;
 
-std::unique_ptr<Node> Graph::createNode(uint32_t id, uint32_t code) {
+std::unique_ptr<Node> Graph::createNode(std::uint32_t id, std::uint32_t code) {
     return std::unique_ptr<Node>(new Node(id, code));
 }
 
-Node::Node(uint32_t id, uint32_t code)
+Node::Node(std::uint32_t id, std::uint32_t code)
         : id_(id), code_(code), in_edges_(), out_edges_(),
         aligned_nodes_ids_() {
 }
@@ -28,7 +27,7 @@ Node::Node(uint32_t id, uint32_t code)
 Node::~Node() {
 }
 
-bool Node::successor(uint32_t& dst, uint32_t label) const {
+bool Node::successor(std::uint32_t& dst, std::uint32_t label) const {
 
     for (const auto& edge: out_edges_) {
         for (const auto& l: edge->sequence_labels_) {
@@ -41,9 +40,9 @@ bool Node::successor(uint32_t& dst, uint32_t label) const {
     return false;
 }
 
-uint32_t Node::coverage() const {
+std::uint32_t Node::coverage() const {
 
-    std::unordered_set<uint32_t> label_set;
+    std::unordered_set<std::uint32_t> label_set;
     for (const auto& edge: in_edges_) {
         for (const auto& label: edge->sequence_labels_) {
             label_set.insert(label);
@@ -57,15 +56,15 @@ uint32_t Node::coverage() const {
     return label_set.size();
 }
 
-std::unique_ptr<Edge> Graph::createEdge(uint32_t begin_node_id,
-    uint32_t end_node_id, uint32_t label, uint32_t weight) {
+std::unique_ptr<Edge> Graph::createEdge(std::uint32_t begin_node_id,
+    std::uint32_t end_node_id, std::uint32_t label, std::uint32_t weight) {
 
     return std::unique_ptr<Edge>(new Edge(begin_node_id, end_node_id, label,
         weight));
 }
 
-Edge::Edge(uint32_t begin_node_id, uint32_t end_node_id, uint32_t label,
-    uint32_t weight)
+Edge::Edge(std::uint32_t begin_node_id, std::uint32_t end_node_id,
+    std::uint32_t label, std::uint32_t weight)
         : begin_node_id_(begin_node_id), end_node_id_(end_node_id),
         sequence_labels_(1, label), total_weight_(weight) {
 }
@@ -73,7 +72,7 @@ Edge::Edge(uint32_t begin_node_id, uint32_t end_node_id, uint32_t label,
 Edge::~Edge() {
 }
 
-void Edge::add_sequence(uint32_t label, uint32_t weight) {
+void Edge::add_sequence(std::uint32_t label, std::uint32_t weight) {
     sequence_labels_.emplace_back(label);
     total_weight_ += weight;
 }
@@ -91,14 +90,14 @@ Graph::Graph()
 Graph::~Graph() {
 }
 
-uint32_t Graph::add_node(uint32_t code) {
-    uint32_t node_id = nodes_.size();
+std::uint32_t Graph::add_node(std::uint32_t code) {
+    std::uint32_t node_id = nodes_.size();
     nodes_.emplace_back(createNode(node_id, code));
     return node_id;
 }
 
-void Graph::add_edge(uint32_t begin_node_id, uint32_t end_node_id,
-    uint32_t weight) {
+void Graph::add_edge(std::uint32_t begin_node_id, std::uint32_t end_node_id,
+    std::uint32_t weight) {
 
     assert(begin_node_id < nodes_.size() && end_node_id < nodes_.size());
 
@@ -116,56 +115,54 @@ void Graph::add_edge(uint32_t begin_node_id, uint32_t end_node_id,
 }
 
 void Graph::add_alignment(const Alignment& alignment,
-    const std::string& sequence, uint32_t weight) {
+    const std::string& sequence, std::uint32_t weight) {
 
-    this->add_alignment(alignment, sequence.c_str(), sequence.size(), weight);
+    add_alignment(alignment, sequence.c_str(), sequence.size(), weight);
 }
 
 void Graph::add_alignment(const Alignment& alignment, const char* sequence,
-    uint32_t sequence_size, uint32_t weight) {
+    std::uint32_t sequence_size, std::uint32_t weight) {
 
-    std::vector<uint32_t> weights(sequence_size, weight);
-    this->add_alignment(alignment, sequence, sequence_size, weights);
+    std::vector<std::uint32_t> weights(sequence_size, weight);
+    add_alignment(alignment, sequence, sequence_size, weights);
 }
 
 void Graph::add_alignment(const Alignment& alignment, const std::string& sequence,
     const std::string& quality) {
 
-    this->add_alignment(alignment, sequence.c_str(), sequence.size(),
+    add_alignment(alignment, sequence.c_str(), sequence.size(),
         quality.c_str(), quality.size());
 }
 
 void Graph::add_alignment(const Alignment& alignment, const char* sequence,
-    uint32_t sequence_size, const char* quality, uint32_t quality_size) {
+    std::uint32_t sequence_size, const char* quality,
+    std::uint32_t quality_size) {
 
-    std::vector<uint32_t> weights;
-    for (uint32_t i = 0; i < quality_size; ++i) {
-        weights.emplace_back(static_cast<uint32_t>(quality[i] - 33)); // PHRED quality
+    std::vector<std::uint32_t> weights;
+    for (std::uint32_t i = 0; i < quality_size; ++i) {
+        weights.emplace_back(static_cast<std::uint32_t>(quality[i] - 33)); // PHRED quality
     }
-    this->add_alignment(alignment, sequence, sequence_size, weights);
+    add_alignment(alignment, sequence, sequence_size, weights);
 }
 
 void Graph::add_alignment(const Alignment& alignment, const std::string& sequence,
-    const std::vector<uint32_t>& weights) {
+    const std::vector<std::uint32_t>& weights) {
 
-    this->add_alignment(alignment, sequence.c_str(), sequence.size(), weights);
+    add_alignment(alignment, sequence.c_str(), sequence.size(), weights);
 }
 
 void Graph::add_alignment(const Alignment& alignment, const char* sequence,
-    uint32_t sequence_size, const std::vector<uint32_t>& weights) {
+    std::uint32_t sequence_size, const std::vector<std::uint32_t>& weights) {
 
     if (sequence_size == 0) {
-        fprintf(stderr, "[spoa::Graph::add_alignment] error: "
-            "empty sequence!\n");
-        exit(1);
+        return;
     }
     if (sequence_size != weights.size()) {
-        fprintf(stderr, "[spoa::Graph::add_alignment] error: "
+        throw std::invalid_argument("[spoa::Graph::add_alignment] error: "
             "sequence and weights are of unequal size!");
-        exit(1);
     }
 
-    for (uint32_t i = 0; i < sequence_size; ++i) {
+    for (std::uint32_t i = 0; i < sequence_size; ++i) {
         auto c = sequence[i];
         if (coder_[c] == -1) {
             coder_[c] = num_codes_;
@@ -175,16 +172,16 @@ void Graph::add_alignment(const Alignment& alignment, const char* sequence,
     }
 
     if (alignment.empty()) { // no alignment
-        int32_t begin_node_id = this->add_sequence(sequence, weights, 0,
+        std::int32_t begin_node_id = add_sequence(sequence, weights, 0,
             sequence_size);
         ++num_sequences_;
         sequences_begin_nodes_ids_.emplace_back(begin_node_id);
 
-        this->topological_sort();
+        topological_sort();
         return;
     }
 
-    std::vector<uint32_t> valid_seq_ids;
+    std::vector<std::uint32_t> valid_seq_ids;
     for (const auto& it: alignment) {
         if (it.second != -1) {
             valid_seq_ids.emplace_back(it.second);
@@ -194,33 +191,33 @@ void Graph::add_alignment(const Alignment& alignment, const char* sequence,
     assert(valid_seq_ids.front() <= sequence_size);
     assert(valid_seq_ids.back() + 1 <= sequence_size);
 
-    uint32_t tmp = nodes_.size();
-    int32_t begin_node_id = this->add_sequence(sequence, weights, 0,
+    std::uint32_t tmp = nodes_.size();
+    std::int32_t begin_node_id = add_sequence(sequence, weights, 0,
         valid_seq_ids.front());
-    int32_t head_node_id = tmp == nodes_.size() ? -1 : nodes_.size() - 1;
+    std::int32_t head_node_id = tmp == nodes_.size() ? -1 : nodes_.size() - 1;
 
-    int32_t tail_node_id = this->add_sequence(sequence, weights,
+    std::int32_t tail_node_id = add_sequence(sequence, weights,
         valid_seq_ids.back() + 1, sequence_size);
 
-    int32_t new_node_id = -1;
+    std::int32_t new_node_id = -1;
     float prev_weight = head_node_id == -1 ?
         0 : weights[valid_seq_ids.front() - 1];
 
-    for (uint32_t i = 0; i < alignment.size(); ++i) {
+    for (std::uint32_t i = 0; i < alignment.size(); ++i) {
         if (alignment[i].second == -1) {
             continue;
         }
 
         char letter = sequence[alignment[i].second];
         if (alignment[i].first == -1) {
-            new_node_id = this->add_node(coder_[letter]);
+            new_node_id = add_node(coder_[letter]);
 
         } else {
             if (decoder_[nodes_[alignment[i].first]->code_] == letter) {
                 new_node_id = alignment[i].first;
 
             } else {
-                int32_t aligned_to_node_id = -1;
+                std::int32_t aligned_to_node_id = -1;
                 for (const auto& aid: nodes_[alignment[i].first]->aligned_nodes_ids_) {
                     if (decoder_[nodes_[aid]->code_] == letter) {
                         aligned_to_node_id = aid;
@@ -229,7 +226,7 @@ void Graph::add_alignment(const Alignment& alignment, const char* sequence,
                 }
 
                 if (aligned_to_node_id == -1) {
-                    new_node_id = this->add_node(coder_[letter]);
+                    new_node_id = add_node(coder_[letter]);
 
                     for (const auto& aid: nodes_[alignment[i].first]->aligned_nodes_ids_) {
                         nodes_[new_node_id]->aligned_nodes_ids_.emplace_back(aid);
@@ -253,7 +250,7 @@ void Graph::add_alignment(const Alignment& alignment, const char* sequence,
 
         if (head_node_id != -1) {
             // both nodes contribute to edge weight
-            this->add_edge(head_node_id, new_node_id,
+            add_edge(head_node_id, new_node_id,
                 prev_weight + weights[alignment[i].second]);
         }
 
@@ -263,30 +260,31 @@ void Graph::add_alignment(const Alignment& alignment, const char* sequence,
 
     if (tail_node_id != -1) {
         // both nodes contribute to edge weight
-        this->add_edge(head_node_id, tail_node_id,
+        add_edge(head_node_id, tail_node_id,
             prev_weight + weights[valid_seq_ids.back() + 1]);
     }
 
     ++num_sequences_;
     sequences_begin_nodes_ids_.emplace_back(begin_node_id);
 
-    this->topological_sort();
+    topological_sort();
 }
 
-int32_t Graph::add_sequence(const char* sequence, const std::vector<uint32_t>& weights,
-    uint32_t begin, uint32_t end) {
+std::int32_t Graph::add_sequence(const char* sequence,
+    const std::vector<std::uint32_t>& weights, std::uint32_t begin,
+    std::uint32_t end) {
 
     if (begin == end) {
         return -1;
     }
 
-    int32_t first_node_id = this->add_node(coder_[sequence[begin]]);
+    std::int32_t first_node_id = add_node(coder_[sequence[begin]]);
 
-    uint32_t node_id;
-    for (uint32_t i = begin + 1; i < end; ++i) {
-        node_id = this->add_node(coder_[sequence[i]]);
+    std::uint32_t node_id;
+    for (std::uint32_t i = begin + 1; i < end; ++i) {
+        node_id = add_node(coder_[sequence[i]]);
         // both nodes contribute to edge weight
-        this->add_edge(node_id - 1, node_id, weights[i - 1] + weights[i]);
+        add_edge(node_id - 1, node_id, weights[i - 1] + weights[i]);
     }
 
     return first_node_id;
@@ -297,18 +295,18 @@ void Graph::topological_sort() {
     rank_to_node_id_.clear();
 
     // 0 - unmarked, 1 - temporarily marked, 2 - permanently marked
-    std::vector<uint8_t> node_marks(nodes_.size(), 0);
+    std::vector<std::uint8_t> node_marks(nodes_.size(), 0);
     std::vector<bool> check_aligned_nodes(nodes_.size(), true);
-    std::stack<uint32_t> nodes_to_visit;
+    std::stack<std::uint32_t> nodes_to_visit;
 
-    for (uint32_t i = 0; i < nodes_.size(); ++i) {
+    for (std::uint32_t i = 0; i < nodes_.size(); ++i) {
         if (node_marks[i] != 0) {
             continue;
         }
 
         nodes_to_visit.push(i);
         while (nodes_to_visit.size() != 0) {
-            uint32_t node_id = nodes_to_visit.top();
+            std::uint32_t node_id = nodes_to_visit.top();
             bool valid = true;
 
             if (node_marks[node_id] != 2) {
@@ -351,14 +349,14 @@ void Graph::topological_sort() {
         }
     }
 
-    assert(this->is_topologically_sorted() == true);
+    assert(is_topologically_sorted() == true);
 }
 
 bool Graph::is_topologically_sorted() const {
     assert(nodes_.size() == rank_to_node_id_.size());
 
     std::vector<bool> visited_nodes(nodes_.size(), false);
-    for (uint32_t node_id: rank_to_node_id_) {
+    for (std::uint32_t node_id: rank_to_node_id_) {
         for (const auto& edge: nodes_[node_id]->in_edges_) {
             if (visited_nodes[edge->begin_node_id_] == false) {
                 return false;
@@ -370,16 +368,17 @@ bool Graph::is_topologically_sorted() const {
     return true;
 }
 
-uint32_t Graph::initialize_multiple_sequence_alignment(std::vector<uint32_t>& dst) const {
+std::uint32_t Graph::initialize_multiple_sequence_alignment(
+    std::vector<std::uint32_t>& dst) const {
 
     dst.resize(nodes_.size(), 0);
 
-    uint32_t msa_id = 0;
-    for (uint32_t i = 0; i < nodes_.size(); ++i) {
-        uint32_t node_id = rank_to_node_id_[i];
+    std::uint32_t msa_id = 0;
+    for (std::uint32_t i = 0; i < nodes_.size(); ++i) {
+        std::uint32_t node_id = rank_to_node_id_[i];
 
         dst[node_id] = msa_id;
-        for (uint32_t j = 0; j < nodes_[node_id]->aligned_nodes_ids_.size(); ++j) {
+        for (std::uint32_t j = 0; j < nodes_[node_id]->aligned_nodes_ids_.size(); ++j) {
             dst[rank_to_node_id_[++i]] = msa_id;
         }
         ++msa_id;
@@ -392,14 +391,14 @@ void Graph::generate_multiple_sequence_alignment(std::vector<std::string>& dst,
     bool include_consensus) {
 
     // assign msa id to each node
-    std::vector<uint32_t> node_id_to_msa_id;
+    std::vector<std::uint32_t> node_id_to_msa_id;
     auto msa_length = initialize_multiple_sequence_alignment(node_id_to_msa_id);
 
     // extract sequences from graph and create msa strings (add indels(-) where
     // necessary)
-    for (uint32_t i = 0; i < num_sequences_; ++i) {
+    for (std::uint32_t i = 0; i < num_sequences_; ++i) {
         std::string alignment_str(msa_length, '-');
-        uint32_t node_id = sequences_begin_nodes_ids_[i];
+        std::uint32_t node_id = sequences_begin_nodes_ids_[i];
 
         while (true) {
             alignment_str[node_id_to_msa_id[node_id]] =
@@ -415,7 +414,7 @@ void Graph::generate_multiple_sequence_alignment(std::vector<std::string>& dst,
 
     if (include_consensus) {
         // do the same for consensus sequence
-        this->traverse_heaviest_bundle();
+        traverse_heaviest_bundle();
 
         std::string alignment_str(msa_length, '-');
         for (const auto& node_id: consensus_) {
@@ -428,7 +427,7 @@ void Graph::generate_multiple_sequence_alignment(std::vector<std::string>& dst,
 
 std::string Graph::generate_consensus() {
 
-    this->traverse_heaviest_bundle();
+    traverse_heaviest_bundle();
     std::string consensus_str = "";
     for (const auto& node_id: consensus_) {
         consensus_str += decoder_[nodes_[node_id]->code_];
@@ -437,14 +436,15 @@ std::string Graph::generate_consensus() {
     return consensus_str;
 }
 
-std::string Graph::generate_consensus(std::vector<uint32_t>& dst, bool verbose) {
+std::string Graph::generate_consensus(std::vector<std::uint32_t>& dst,
+    bool verbose) {
 
-    auto consensus_str = this->generate_consensus();
+    auto consensus_str = generate_consensus();
 
     dst.clear();
     if (verbose == false) {
         for (const auto& node_id: consensus_) {
-            uint32_t total_coverage = nodes_[node_id]->coverage();
+            std::uint32_t total_coverage = nodes_[node_id]->coverage();
             for (const auto& aid: nodes_[node_id]->aligned_nodes_ids_) {
                 total_coverage += nodes_[aid]->coverage();
             }
@@ -453,14 +453,14 @@ std::string Graph::generate_consensus(std::vector<uint32_t>& dst, bool verbose)
     } else {
         dst.resize((num_codes_ + 1) * consensus_.size(), 0);
 
-        std::vector<uint32_t> node_id_to_msa_id;
+        std::vector<std::uint32_t> node_id_to_msa_id;
         initialize_multiple_sequence_alignment(node_id_to_msa_id);
 
-        for (uint32_t i = 0; i < num_sequences_; ++i) {
+        for (std::uint32_t i = 0; i < num_sequences_; ++i) {
             auto node_id = sequences_begin_nodes_ids_[i];
 
             bool count_indels = false;
-            uint32_t c = 0, l;
+            std::uint32_t c = 0, l;
             while (true) {
                 for (; c < consensus_.size() &&
                     node_id_to_msa_id[consensus_[c]] < node_id_to_msa_id[node_id]; ++c);
@@ -470,7 +470,7 @@ std::string Graph::generate_consensus(std::vector<uint32_t>& dst, bool verbose)
 
                 if (node_id_to_msa_id[consensus_[c]] == node_id_to_msa_id[node_id]) {
                     if (count_indels) {
-                        for (uint32_t j = l + 1; j < c; ++j) {
+                        for (std::uint32_t j = l + 1; j < c; ++j) {
                             ++dst[num_codes_ * consensus_.size() + j];
                         }
                     }
@@ -492,10 +492,10 @@ std::string Graph::generate_consensus(std::vector<uint32_t>& dst, bool verbose)
 
 void Graph::traverse_heaviest_bundle() {
 
-    std::vector<int32_t> predecessors(nodes_.size(), -1);
-    std::vector<int64_t> scores(nodes_.size(), -1);
+    std::vector<std::int32_t> predecessors(nodes_.size(), -1);
+    std::vector<std::int64_t> scores(nodes_.size(), -1);
 
-    uint32_t max_score_id = 0;
+    std::uint32_t max_score_id = 0;
     for (const auto& node_id: rank_to_node_id_) {
         for (const auto& edge: nodes_[node_id]->in_edges_) {
             if (scores[node_id] < edge->total_weight_ ||
@@ -518,13 +518,13 @@ void Graph::traverse_heaviest_bundle() {
 
     if (nodes_[max_score_id]->out_edges_.size() != 0) {
 
-        std::vector<uint32_t> node_id_to_rank(nodes_.size(), 0);
-        for (uint32_t i = 0; i < nodes_.size(); ++i) {
+        std::vector<std::uint32_t> node_id_to_rank(nodes_.size(), 0);
+        for (std::uint32_t i = 0; i < nodes_.size(); ++i) {
             node_id_to_rank[rank_to_node_id_[i]] = i;
         }
 
         while (nodes_[max_score_id]->out_edges_.size() != 0) {
-            max_score_id = this->branch_completion(scores, predecessors,
+            max_score_id = branch_completion(scores, predecessors,
                 node_id_to_rank[max_score_id]);
         }
     }
@@ -540,10 +540,10 @@ void Graph::traverse_heaviest_bundle() {
     std::reverse(consensus_.begin(), consensus_.end());
 }
 
-uint32_t Graph::branch_completion(std::vector<int64_t>& scores,
-    std::vector<int32_t>& predecessors, uint32_t rank) {
+std::uint32_t Graph::branch_completion(std::vector<std::int64_t>& scores,
+    std::vector<std::int32_t>& predecessors, std::uint32_t rank) {
 
-    uint32_t node_id = rank_to_node_id_[rank];
+    std::uint32_t node_id = rank_to_node_id_[rank];
     for (const auto& edge: nodes_[node_id]->out_edges_) {
         for (const auto& o_edge: nodes_[edge->end_node_id_]->in_edges_) {
             if (o_edge->begin_node_id_ != node_id) {
@@ -552,11 +552,11 @@ uint32_t Graph::branch_completion(std::vector<int64_t>& scores,
         }
     }
 
-    int64_t max_score = 0;
-    uint32_t max_score_id = 0;
-    for (uint32_t i = rank + 1; i < rank_to_node_id_.size(); ++i) {
+    std::int64_t max_score = 0;
+    std::uint32_t max_score_id = 0;
+    for (std::uint32_t i = rank + 1; i < rank_to_node_id_.size(); ++i) {
 
-        uint32_t node_id = rank_to_node_id_[i];
+        std::uint32_t node_id = rank_to_node_id_[i];
         scores[node_id] = -1;
         predecessors[node_id] = -1;
 
@@ -589,15 +589,15 @@ uint32_t Graph::branch_completion(std::vector<int64_t>& scores,
 
 // backtracing from right to left!
 void Graph::extract_subgraph_nodes(std::vector<bool>& dst,
-    uint32_t begin_node_id, uint32_t end_node_id) const {
+    std::uint32_t begin_node_id, std::uint32_t end_node_id) const {
 
     dst.resize(nodes_.size(), false);
 
-    std::stack<uint32_t> nodes_to_visit;
+    std::stack<std::uint32_t> nodes_to_visit;
     nodes_to_visit.push(begin_node_id);
 
     while (nodes_to_visit.size() != 0) {
-        uint32_t node_id = nodes_to_visit.top();
+        std::uint32_t node_id = nodes_to_visit.top();
         nodes_to_visit.pop();
 
         if (dst[node_id] == false && node_id >= end_node_id) {
@@ -613,8 +613,9 @@ void Graph::extract_subgraph_nodes(std::vector<bool>& dst,
     }
 }
 
-std::unique_ptr<Graph> Graph::subgraph(uint32_t begin_node_id,
-    uint32_t end_node_id, std::vector<int32_t>& subgraph_to_graph_mapping) const {
+std::unique_ptr<Graph> Graph::subgraph(std::uint32_t begin_node_id,
+    std::uint32_t end_node_id,
+    std::vector<std::int32_t>& subgraph_to_graph_mapping) const {
 
     std::vector<bool> is_subgraph_node;
     extract_subgraph_nodes(is_subgraph_node, end_node_id, begin_node_id);
@@ -623,31 +624,31 @@ std::unique_ptr<Graph> Graph::subgraph(uint32_t begin_node_id,
     auto subgraph = std::unique_ptr<Graph>(new Graph());
     subgraph->num_sequences_ = num_sequences_;
     subgraph->num_codes_ = num_codes_;
-    subgraph->coder_ = std::vector<int32_t>(coder_);
-    subgraph->decoder_ = std::vector<int32_t>(decoder_);
+    subgraph->coder_ = std::vector<std::int32_t>(coder_);
+    subgraph->decoder_ = std::vector<std::int32_t>(decoder_);
 
     // create mapping from subgraph to graph and vice versa and add nodes to
     // subgraph
     subgraph_to_graph_mapping.resize(nodes_.size(), -1);
-    std::vector<int32_t> graph_to_subgraph_mapping(nodes_.size(), -1);
+    std::vector<std::int32_t> graph_to_subgraph_mapping(nodes_.size(), -1);
 
-    for (uint32_t i = 0; i < is_subgraph_node.size(); ++i) {
+    for (std::uint32_t i = 0; i < is_subgraph_node.size(); ++i) {
         if (is_subgraph_node[i] == false) {
             continue;
         }
 
-        uint32_t subgraph_id = subgraph->add_node(nodes_[i]->code_);
+        std::uint32_t subgraph_id = subgraph->add_node(nodes_[i]->code_);
         graph_to_subgraph_mapping[i] = subgraph_id;
         subgraph_to_graph_mapping[subgraph_id] = i;
     }
 
     // add edges and aligned nodes
-    for (uint32_t i = 0; i < is_subgraph_node.size(); ++i) {
+    for (std::uint32_t i = 0; i < is_subgraph_node.size(); ++i) {
         if (is_subgraph_node[i] == false) {
             continue;
         }
 
-        uint32_t subgraph_id = graph_to_subgraph_mapping[i];
+        std::uint32_t subgraph_id = graph_to_subgraph_mapping[i];
 
         for (const auto& edge: nodes_[i]->in_edges_) {
             if (graph_to_subgraph_mapping[edge->begin_node_id_] == -1) {
@@ -671,9 +672,9 @@ std::unique_ptr<Graph> Graph::subgraph(uint32_t begin_node_id,
 }
 
 void Graph::update_alignment(Alignment& alignment,
-    const std::vector<int32_t>& subgraph_to_graph_mapping) const {
+    const std::vector<std::int32_t>& subgraph_to_graph_mapping) const {
 
-    for (uint32_t i = 0; i < alignment.size(); ++i) {
+    for (std::uint32_t i = 0; i < alignment.size(); ++i) {
         if (alignment[i].first != -1) {
             alignment[i].first = subgraph_to_graph_mapping[alignment[i].first];
         }
@@ -688,15 +689,15 @@ void Graph::print_dot(const std::string& path) const {
 
     std::ofstream out(path);
 
-    std::vector<int32_t> in_consensus(nodes_.size(), -1);
-    int32_t rank = 0;
+    std::vector<std::int32_t> in_consensus(nodes_.size(), -1);
+    std::int32_t rank = 0;
     for (const auto& id: consensus_) {
         in_consensus[id] = rank++;
     }
 
     out << "digraph " << num_sequences_ << " {" << std::endl;
     out << "    graph [rankdir=LR]" << std::endl;
-    for (uint32_t i = 0; i < nodes_.size(); ++i) {
+    for (std::uint32_t i = 0; i < nodes_.size(); ++i) {
         out << "    " << i << " [label = \"" << i << " - ";
         out << static_cast<char>(decoder_[nodes_[i]->code_]) << "\"";
         if (in_consensus[i] != -1) {
@@ -724,4 +725,13 @@ void Graph::print_dot(const std::string& path) const {
     out.close();
 }
 
+void Graph::clear() {
+    std::fill(coder_.begin(), coder_.end(), -1);
+    std::fill(decoder_.begin(), decoder_.end(), -1);
+    nodes_.clear();
+    rank_to_node_id_.clear();
+    sequences_begin_nodes_ids_.clear();
+    consensus_.clear();
+}
+
 }
